@@ -69,7 +69,7 @@ extern "C" {
 /* Key purpose Object Identifiers.
  */
 #define GNUTLS_KP_TLS_WWW_SERVER		"1.3.6.1.5.5.7.3.1"
-#define GNUTLS_KP_TLS_WWW_CLIENT		"1.3.6.1.5.5.7.3.2"
+#define GNUTLS_KP_TLS_WWW_CLIENT                "1.3.6.1.5.5.7.3.2"
 #define GNUTLS_KP_CODE_SIGNING			"1.3.6.1.5.5.7.3.3"
 #define GNUTLS_KP_EMAIL_PROTECTION		"1.3.6.1.5.5.7.3.4"
 #define GNUTLS_KP_TIME_STAMPING			"1.3.6.1.5.5.7.3.8"
@@ -79,10 +79,20 @@ extern "C" {
 /* Certificate handling functions 
  */
 
+typedef enum gnutls_certificate_import_flags {
+    GNUTLS_X509_CRT_LIST_IMPORT_FAIL_IF_EXCEED=1 
+         /* Fail if the certificates in the buffer are more than
+          * the space allocated for certificates. The error code
+          * will be GNUTLS_E_SHORT_MEMORY_BUFFER.
+          */
+} gnutls_certificate_import_flags;
+
 int gnutls_x509_crt_init(gnutls_x509_crt_t * cert);
 void gnutls_x509_crt_deinit(gnutls_x509_crt_t cert);
 int gnutls_x509_crt_import(gnutls_x509_crt_t cert, const gnutls_datum_t * data,
     gnutls_x509_crt_fmt_t format);
+int gnutls_x509_crt_list_import(gnutls_x509_crt_t *certs, unsigned int *cert_max,
+    const gnutls_datum_t * data, gnutls_x509_crt_fmt_t format, unsigned int flags);
 int gnutls_x509_crt_export( gnutls_x509_crt_t cert,
     gnutls_x509_crt_fmt_t format, void* output_data, size_t* output_data_size);
 int gnutls_x509_crt_get_issuer_dn(gnutls_x509_crt_t cert, char *buf,
@@ -161,6 +171,9 @@ int gnutls_x509_crt_get_extension_oid(gnutls_x509_crt_t cert, int indx,
 int gnutls_x509_crt_get_extension_by_oid(gnutls_x509_crt_t cert, 
     const char* oid, int indx,
     void* buf, size_t * sizeof_buf, unsigned int * critical);
+int gnutls_x509_crt_set_extension_by_oid(gnutls_x509_crt_t crt,
+    const char *oid, const void *buf, size_t sizeof_buf,
+    unsigned int critical);
 
 int gnutls_x509_crt_to_xml(gnutls_x509_crt_t cert, gnutls_datum_t* res, int detail);
 
@@ -230,8 +243,9 @@ time_t gnutls_x509_crl_get_this_update(gnutls_x509_crl_t crl);
 time_t gnutls_x509_crl_get_next_update(gnutls_x509_crl_t crl);
 
 int gnutls_x509_crl_get_crt_count(gnutls_x509_crl_t crl);
-int gnutls_x509_crl_get_crt_serial(gnutls_x509_crl_t crl, int index, unsigned char* serial,
-    size_t* serial_size, time_t* time);
+int gnutls_x509_crl_get_crt_serial(gnutls_x509_crl_t crl, int indx,
+				   unsigned char* serial, size_t* serial_size,
+				   time_t* t);
 #define gnutls_x509_crl_get_certificate_count gnutls_x509_crl_get_crt_count
 #define gnutls_x509_crl_get_certificate gnutls_x509_crl_get_crt_serial
 
@@ -288,16 +302,22 @@ int gnutls_pkcs7_delete_crl(gnutls_pkcs7_t pkcs7, int indx);
 
 typedef enum gnutls_certificate_verify_flags {
     GNUTLS_VERIFY_DISABLE_CA_SIGN=1, /* if set a signer does not have to be
-                                      * a certificate authority.
+                                      * a certificate authority. This flag should normaly 
+                                      * be disabled, unless you know what this means.
                                       */
-    GNUTLS_VERIFY_ALLOW_X509_V1_CA_CRT=2,/* Allow CA certificates that have version 1.
-	                                  * This might be dangerous since those haven't
-	                                  * the basicConstraints extension.
-					  */
-    GNUTLS_VERIFY_DO_NOT_ALLOW_SAME=4 /* If a certificate is not signed by anyone
-                                       * trusted but exists in the trusted ca list
+    GNUTLS_VERIFY_ALLOW_X509_V1_CA_CRT=2, /* Allow only trusted CA certificates that have version 1.
+                                           * This is safer than GNUTLS_VERIFY_ALLOW_ANY_X509_V1_CA_CRT,
+                                           * and should be used instead. That way only signers in your 
+                                           * trusted list will be allowed to have certificates of version 1.
+                                           */
+    GNUTLS_VERIFY_DO_NOT_ALLOW_SAME=4,/* If a certificate is not signed by anyone
+                                       * trusted but exists in the trusted CA list
                                        * do not treat it as trusted.
                                        */
+    GNUTLS_VERIFY_ALLOW_ANY_X509_V1_CA_CRT=8 /* Allow CA certificates that have version 1 (both root
+                                              * and intermediate). This might be dangerous since those haven't
+	                                      * the basicConstraints extension.
+					      */
 } gnutls_certificate_verify_flags;
 
 int gnutls_x509_crt_check_issuer( gnutls_x509_crt_t cert,
@@ -424,12 +444,18 @@ int gnutls_x509_crq_set_challenge_password(gnutls_x509_crq_t crq, const char* pa
 int gnutls_x509_crq_get_challenge_password(gnutls_x509_crq_t crq, 
     const char* pass, size_t* sizeof_pass);
 
+int gnutls_x509_crq_set_attribute_by_oid(gnutls_x509_crq_t crq,
+    const char* oid, void* buf, size_t sizeof_buf);
+int gnutls_x509_crq_get_attribute_by_oid(gnutls_x509_crq_t crq,
+    const char* oid, int indx, void* buf, size_t* sizeof_buf);
+
 int gnutls_x509_crq_export( gnutls_x509_crq_t crq,
     gnutls_x509_crt_fmt_t format, void* output_data, size_t* output_data_size);
 
 int gnutls_x509_crt_set_crq(gnutls_x509_crt_t crt, gnutls_x509_crq_t crq);
 
 
+
 #ifdef __cplusplus
 }
 #endif
