@@ -169,10 +169,10 @@ struct gnutls_hash_entry {
 typedef struct gnutls_hash_entry gnutls_hash_entry;
 
 static const gnutls_hash_entry hash_algorithms[] = {
-    {"SHA", OID_SHA1, GNUTLS_MAC_SHA},
-    {"MD5", OID_MD5, GNUTLS_MAC_MD5},
-    {"MD2", OID_MD2, 0/*GNUTLS_MAC_MD2*/},
-    {"RIPEMD160", OID_RMD160, GNUTLS_MAC_RMD160},
+    {"SHA", HASH_OID_SHA1, GNUTLS_MAC_SHA1},
+    {"MD5", HASH_OID_MD5, GNUTLS_MAC_MD5},
+    {"MD2", HASH_OID_MD2, 0/*GNUTLS_MAC_MD2*/},
+    {"RIPEMD160", HASH_OID_RMD160, GNUTLS_MAC_RMD160},
     {"NULL", NULL, GNUTLS_MAC_NULL},
     {0, 0, 0}
 };
@@ -282,46 +282,46 @@ typedef struct {
 /* ANONymous cipher suites.
  */
 
-#define GNUTLS_ANON_DH_3DES_EDE_CBC_SHA { 0x00, 0x1B }
+#define GNUTLS_ANON_DH_3DES_EDE_CBC_SHA1 { 0x00, 0x1B }
 #define GNUTLS_ANON_DH_ARCFOUR_MD5 { 0x00, 0x18 }
 
  /* rfc3268: */
-#define GNUTLS_ANON_DH_AES_128_CBC_SHA { 0x00, 0x34 }
-#define GNUTLS_ANON_DH_AES_256_CBC_SHA { 0x00, 0x3A }
+#define GNUTLS_ANON_DH_AES_128_CBC_SHA1 { 0x00, 0x34 }
+#define GNUTLS_ANON_DH_AES_256_CBC_SHA1 { 0x00, 0x3A }
 
 /* SRP (not in TLS 1.0)
  * draft-ietf-tls-srp-02:
  */
-#define GNUTLS_SRP_SHA_3DES_EDE_CBC_SHA { 0x00, 0x50 }
-#define GNUTLS_SRP_SHA_AES_128_CBC_SHA { 0x00, 0x53 }
-#define GNUTLS_SRP_SHA_AES_256_CBC_SHA { 0x00, 0x56 }
+#define GNUTLS_SRP_SHA_3DES_EDE_CBC_SHA1 { 0x00, 0x50 }
+#define GNUTLS_SRP_SHA_AES_128_CBC_SHA1 { 0x00, 0x53 }
+#define GNUTLS_SRP_SHA_AES_256_CBC_SHA1 { 0x00, 0x56 }
 
-#define GNUTLS_SRP_SHA_RSA_3DES_EDE_CBC_SHA { 0x00, 0x51 }
-#define GNUTLS_SRP_SHA_DSS_3DES_EDE_CBC_SHA { 0x00, 0x52 }
+#define GNUTLS_SRP_SHA_RSA_3DES_EDE_CBC_SHA1 { 0x00, 0x51 }
+#define GNUTLS_SRP_SHA_DSS_3DES_EDE_CBC_SHA1 { 0x00, 0x52 }
 
-#define GNUTLS_SRP_SHA_RSA_AES_128_CBC_SHA { 0x00, 0x54 }
-#define GNUTLS_SRP_SHA_DSS_AES_128_CBC_SHA { 0x00, 0x55 }
+#define GNUTLS_SRP_SHA_RSA_AES_128_CBC_SHA1 { 0x00, 0x54 }
+#define GNUTLS_SRP_SHA_DSS_AES_128_CBC_SHA1 { 0x00, 0x55 }
 
-#define GNUTLS_SRP_SHA_RSA_AES_256_CBC_SHA { 0x00, 0x57 }
-#define GNUTLS_SRP_SHA_DSS_AES_256_CBC_SHA { 0x00, 0x58 }
+#define GNUTLS_SRP_SHA_RSA_AES_256_CBC_SHA1 { 0x00, 0x57 }
+#define GNUTLS_SRP_SHA_DSS_AES_256_CBC_SHA1 { 0x00, 0x58 }
 
 /* RSA
  */
-#define GNUTLS_RSA_ARCFOUR_SHA { 0x00, 0x05 }
+#define GNUTLS_RSA_ARCFOUR_SHA1 { 0x00, 0x05 }
 #define GNUTLS_RSA_ARCFOUR_MD5 { 0x00, 0x04 }
-#define GNUTLS_RSA_3DES_EDE_CBC_SHA { 0x00, 0x0A }
+#define GNUTLS_RSA_3DES_EDE_CBC_SHA1 { 0x00, 0x0A }
 
 #define GNUTLS_RSA_EXPORT_ARCFOUR_40_MD5 { 0x00, 0x03 }
 
 /* rfc3268:
  */
-#define GNUTLS_RSA_AES_128_CBC_SHA { 0x00, 0x2F }
-#define GNUTLS_RSA_AES_256_CBC_SHA { 0x00, 0x35 }
+#define GNUTLS_RSA_AES_128_CBC_SHA1 { 0x00, 0x2F }
+#define GNUTLS_RSA_AES_256_CBC_SHA1 { 0x00, 0x35 }
 
 /* DHE DSS
  */
 
-#define GNUTLS_DHE_DSS_3DES_EDE_CBC_SHA { 0x00, 0x13 }
+#define GNUTLS_DHE_DSS_3DES_EDE_CBC_SHA1 { 0x00, 0x13 }
 
 
 /* draft-ietf-tls-openpgp-keys-04:
@@ -339,22 +339,22 @@ typedef struct {
 
 /* draft-ietf-tls-56-bit-ciphersuites-01:
  */
-#define GNUTLS_DHE_DSS_ARCFOUR_SHA { 0x00, 0x66 }
+#define GNUTLS_DHE_DSS_ARCFOUR_SHA1 { 0x00, 0x66 }
 
 
 /* rfc3268:
  */
-#define GNUTLS_DHE_DSS_AES_256_CBC_SHA { 0x00, 0x38 }
-#define GNUTLS_DHE_DSS_AES_128_CBC_SHA { 0x00, 0x32 }
+#define GNUTLS_DHE_DSS_AES_256_CBC_SHA1 { 0x00, 0x38 }
+#define GNUTLS_DHE_DSS_AES_128_CBC_SHA1 { 0x00, 0x32 }
 
 /* DHE RSA
  */
-#define GNUTLS_DHE_RSA_3DES_EDE_CBC_SHA { 0x00, 0x16 }
+#define GNUTLS_DHE_RSA_3DES_EDE_CBC_SHA1 { 0x00, 0x16 }
 
 /* rfc3268:
  */
-#define GNUTLS_DHE_RSA_AES_128_CBC_SHA { 0x00, 0x33 }
-#define GNUTLS_DHE_RSA_AES_256_CBC_SHA { 0x00, 0x39 }
+#define GNUTLS_DHE_RSA_AES_128_CBC_SHA1 { 0x00, 0x33 }
+#define GNUTLS_DHE_RSA_AES_256_CBC_SHA1 { 0x00, 0x39 }
 
 #define CIPHER_SUITES_COUNT sizeof(cs_algorithms)/sizeof(gnutls_cipher_suite_entry)-1
 
@@ -364,63 +364,63 @@ static const gnutls_cipher_suite_entry cs_algorithms[] = {
 			      GNUTLS_CIPHER_ARCFOUR_128,
 			      GNUTLS_KX_ANON_DH, GNUTLS_MAC_MD5,
 			      GNUTLS_SSL3),
-    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_ANON_DH_3DES_EDE_CBC_SHA,
+    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_ANON_DH_3DES_EDE_CBC_SHA1,
 			      GNUTLS_CIPHER_3DES_CBC, GNUTLS_KX_ANON_DH,
-			      GNUTLS_MAC_SHA, GNUTLS_SSL3),
-    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_ANON_DH_AES_128_CBC_SHA,
+			      GNUTLS_MAC_SHA1, GNUTLS_SSL3),
+    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_ANON_DH_AES_128_CBC_SHA1,
 			      GNUTLS_CIPHER_AES_128_CBC, GNUTLS_KX_ANON_DH,
-			      GNUTLS_MAC_SHA, GNUTLS_SSL3),
-    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_ANON_DH_AES_256_CBC_SHA,
+			      GNUTLS_MAC_SHA1, GNUTLS_SSL3),
+    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_ANON_DH_AES_256_CBC_SHA1,
 			      GNUTLS_CIPHER_AES_256_CBC, GNUTLS_KX_ANON_DH,
-			      GNUTLS_MAC_SHA, GNUTLS_SSL3),
+			      GNUTLS_MAC_SHA1, GNUTLS_SSL3),
     /* SRP */
-    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_3DES_EDE_CBC_SHA,
+    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_3DES_EDE_CBC_SHA1,
 			      GNUTLS_CIPHER_3DES_CBC, GNUTLS_KX_SRP,
-			      GNUTLS_MAC_SHA, GNUTLS_TLS1),
-    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_AES_128_CBC_SHA,
+			      GNUTLS_MAC_SHA1, GNUTLS_TLS1),
+    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_AES_128_CBC_SHA1,
 			      GNUTLS_CIPHER_AES_128_CBC, GNUTLS_KX_SRP,
-			      GNUTLS_MAC_SHA, GNUTLS_TLS1),
-    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_AES_256_CBC_SHA,
+			      GNUTLS_MAC_SHA1, GNUTLS_TLS1),
+    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_AES_256_CBC_SHA1,
 			      GNUTLS_CIPHER_AES_256_CBC, GNUTLS_KX_SRP,
-			      GNUTLS_MAC_SHA, GNUTLS_TLS1),
+			      GNUTLS_MAC_SHA1, GNUTLS_TLS1),
 
-    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_DSS_3DES_EDE_CBC_SHA,
+    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_DSS_3DES_EDE_CBC_SHA1,
 			      GNUTLS_CIPHER_3DES_CBC, GNUTLS_KX_SRP_DSS,
-			      GNUTLS_MAC_SHA, GNUTLS_TLS1),
+			      GNUTLS_MAC_SHA1, GNUTLS_TLS1),
 
-    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_RSA_3DES_EDE_CBC_SHA,
+    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_RSA_3DES_EDE_CBC_SHA1,
 			      GNUTLS_CIPHER_3DES_CBC, GNUTLS_KX_SRP_RSA,
-			      GNUTLS_MAC_SHA, GNUTLS_TLS1),
+			      GNUTLS_MAC_SHA1, GNUTLS_TLS1),
 
-    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_DSS_AES_128_CBC_SHA,
+    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_DSS_AES_128_CBC_SHA1,
 			      GNUTLS_CIPHER_AES_128_CBC, GNUTLS_KX_SRP_DSS,
-			      GNUTLS_MAC_SHA, GNUTLS_TLS1),
+			      GNUTLS_MAC_SHA1, GNUTLS_TLS1),
 
-    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_RSA_AES_128_CBC_SHA,
+    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_RSA_AES_128_CBC_SHA1,
 			      GNUTLS_CIPHER_AES_128_CBC, GNUTLS_KX_SRP_RSA,
-			      GNUTLS_MAC_SHA, GNUTLS_TLS1),
+			      GNUTLS_MAC_SHA1, GNUTLS_TLS1),
 
-    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_DSS_AES_256_CBC_SHA,
+    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_DSS_AES_256_CBC_SHA1,
 			      GNUTLS_CIPHER_AES_256_CBC, GNUTLS_KX_SRP_DSS,
-			      GNUTLS_MAC_SHA, GNUTLS_TLS1),
+			      GNUTLS_MAC_SHA1, GNUTLS_TLS1),
 
-    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_RSA_AES_256_CBC_SHA,
+    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_RSA_AES_256_CBC_SHA1,
 			      GNUTLS_CIPHER_AES_256_CBC, GNUTLS_KX_SRP_RSA,
-			      GNUTLS_MAC_SHA, GNUTLS_TLS1),
+			      GNUTLS_MAC_SHA1, GNUTLS_TLS1),
 
     /* DHE_DSS */
-    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_DSS_ARCFOUR_SHA,
+    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_DSS_ARCFOUR_SHA1,
 			      GNUTLS_CIPHER_ARCFOUR_128, GNUTLS_KX_DHE_DSS,
-			      GNUTLS_MAC_SHA, GNUTLS_TLS1),
-    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_DSS_3DES_EDE_CBC_SHA,
+			      GNUTLS_MAC_SHA1, GNUTLS_TLS1),
+    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_DSS_3DES_EDE_CBC_SHA1,
 			      GNUTLS_CIPHER_3DES_CBC, GNUTLS_KX_DHE_DSS,
-			      GNUTLS_MAC_SHA, GNUTLS_SSL3),
-    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_DSS_AES_128_CBC_SHA,
+			      GNUTLS_MAC_SHA1, GNUTLS_SSL3),
+    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_DSS_AES_128_CBC_SHA1,
 			      GNUTLS_CIPHER_AES_128_CBC, GNUTLS_KX_DHE_DSS,
-			      GNUTLS_MAC_SHA, GNUTLS_SSL3),
-    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_DSS_AES_256_CBC_SHA,
+			      GNUTLS_MAC_SHA1, GNUTLS_SSL3),
+    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_DSS_AES_256_CBC_SHA1,
 			      GNUTLS_CIPHER_AES_256_CBC, GNUTLS_KX_DHE_DSS,
-			      GNUTLS_MAC_SHA, GNUTLS_SSL3),
+			      GNUTLS_MAC_SHA1, GNUTLS_SSL3),
     GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_DSS_3DES_EDE_CBC_RMD,
 			      GNUTLS_CIPHER_3DES_CBC, GNUTLS_KX_DHE_DSS,
 			      GNUTLS_MAC_RMD160, GNUTLS_TLS1),
@@ -431,15 +431,15 @@ static const gnutls_cipher_suite_entry cs_algorithms[] = {
 			      GNUTLS_CIPHER_AES_256_CBC, GNUTLS_KX_DHE_DSS,
 			      GNUTLS_MAC_RMD160, GNUTLS_TLS1),
     /* DHE_RSA */
-    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_RSA_3DES_EDE_CBC_SHA,
+    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_RSA_3DES_EDE_CBC_SHA1,
 			      GNUTLS_CIPHER_3DES_CBC, GNUTLS_KX_DHE_RSA,
-			      GNUTLS_MAC_SHA, GNUTLS_SSL3),
-    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_RSA_AES_128_CBC_SHA,
+			      GNUTLS_MAC_SHA1, GNUTLS_SSL3),
+    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_RSA_AES_128_CBC_SHA1,
 			      GNUTLS_CIPHER_AES_128_CBC, GNUTLS_KX_DHE_RSA,
-			      GNUTLS_MAC_SHA, GNUTLS_SSL3),
-    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_RSA_AES_256_CBC_SHA,
+			      GNUTLS_MAC_SHA1, GNUTLS_SSL3),
+    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_RSA_AES_256_CBC_SHA1,
 			      GNUTLS_CIPHER_AES_256_CBC, GNUTLS_KX_DHE_RSA,
-			      GNUTLS_MAC_SHA, GNUTLS_SSL3),
+			      GNUTLS_MAC_SHA1, GNUTLS_SSL3),
     GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_RSA_3DES_EDE_CBC_RMD,
 			      GNUTLS_CIPHER_3DES_CBC, GNUTLS_KX_DHE_RSA,
 			      GNUTLS_MAC_RMD160, GNUTLS_TLS1),
@@ -459,21 +459,21 @@ static const gnutls_cipher_suite_entry cs_algorithms[] = {
 			      GNUTLS_KX_RSA_EXPORT, GNUTLS_MAC_MD5,
 			      GNUTLS_SSL3),
 
-    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_ARCFOUR_SHA,
+    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_ARCFOUR_SHA1,
 			      GNUTLS_CIPHER_ARCFOUR_128,
-			      GNUTLS_KX_RSA, GNUTLS_MAC_SHA, GNUTLS_SSL3),
+			      GNUTLS_KX_RSA, GNUTLS_MAC_SHA1, GNUTLS_SSL3),
     GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_ARCFOUR_MD5,
 			      GNUTLS_CIPHER_ARCFOUR_128,
 			      GNUTLS_KX_RSA, GNUTLS_MAC_MD5, GNUTLS_SSL3),
-    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_3DES_EDE_CBC_SHA,
+    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_3DES_EDE_CBC_SHA1,
 			      GNUTLS_CIPHER_3DES_CBC,
-			      GNUTLS_KX_RSA, GNUTLS_MAC_SHA, GNUTLS_SSL3),
-    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_AES_128_CBC_SHA,
+			      GNUTLS_KX_RSA, GNUTLS_MAC_SHA1, GNUTLS_SSL3),
+    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_AES_128_CBC_SHA1,
 			      GNUTLS_CIPHER_AES_128_CBC, GNUTLS_KX_RSA,
-			      GNUTLS_MAC_SHA, GNUTLS_SSL3),
-    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_AES_256_CBC_SHA,
+			      GNUTLS_MAC_SHA1, GNUTLS_SSL3),
+    GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_AES_256_CBC_SHA1,
 			      GNUTLS_CIPHER_AES_256_CBC, GNUTLS_KX_RSA,
-			      GNUTLS_MAC_SHA, GNUTLS_SSL3),
+			      GNUTLS_MAC_SHA1, GNUTLS_SSL3),
     GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_3DES_EDE_CBC_RMD,
 			      GNUTLS_CIPHER_3DES_CBC,
 			      GNUTLS_KX_RSA, GNUTLS_MAC_RMD160,
@@ -1425,11 +1425,13 @@ struct gnutls_sign_entry {
 typedef struct gnutls_sign_entry gnutls_sign_entry;
 
 static const gnutls_sign_entry sign_algorithms[] = {
-    {"RSA-SHA", RSA_SHA1_OID, GNUTLS_SIGN_RSA_SHA, GNUTLS_PK_RSA, GNUTLS_MAC_SHA},
-    {"RSA-RMD160", RSA_RMD160_OID, GNUTLS_SIGN_RSA_RMD160, GNUTLS_PK_RSA, GNUTLS_MAC_RMD160},
-    {"DSA-SHA", DSA_SHA1_OID, GNUTLS_SIGN_DSA_SHA, GNUTLS_PK_DSA, GNUTLS_MAC_SHA},
-    {"RSA-MD5", RSA_MD5_OID, GNUTLS_SIGN_RSA_MD5, GNUTLS_PK_RSA, GNUTLS_MAC_MD5},
-    {"RSA-MD2", RSA_MD2_OID, GNUTLS_SIGN_RSA_MD2, GNUTLS_PK_RSA, 0/*GNUTLS_MAC_MD2*/},
+    {"RSA-SHA", SIG_RSA_SHA1_OID, GNUTLS_SIGN_RSA_SHA1, GNUTLS_PK_RSA, GNUTLS_MAC_SHA1},
+    {"RSA-RMD160", SIG_RSA_RMD160_OID, GNUTLS_SIGN_RSA_RMD160, GNUTLS_PK_RSA, GNUTLS_MAC_RMD160},
+    {"DSA-SHA", SIG_DSA_SHA1_OID, GNUTLS_SIGN_DSA_SHA1, GNUTLS_PK_DSA, GNUTLS_MAC_SHA1},
+    {"RSA-MD5", SIG_RSA_MD5_OID, GNUTLS_SIGN_RSA_MD5, GNUTLS_PK_RSA, GNUTLS_MAC_MD5},
+    {"RSA-MD2", SIG_RSA_MD2_OID, GNUTLS_SIGN_RSA_MD2, GNUTLS_PK_RSA, 0/*GNUTLS_MAC_MD2*/},
+    {"GOST R 34.10-2001", SIG_GOST_R3410_2001_OID, 0, 0, 0},
+    {"GOST R 34.10-94", SIG_GOST_R3410_94_OID, 0, 0, 0},
     {0, 0, 0, 0, 0}
 };
 
@@ -1511,8 +1513,10 @@ struct gnutls_pk_entry {
 typedef struct gnutls_pk_entry gnutls_pk_entry;
 
 static const gnutls_pk_entry pk_algorithms[] = {
-    {"RSA", PKIX1_RSA_OID, GNUTLS_PK_RSA},
-    {"DSA", DSA_OID, GNUTLS_PK_DSA},
+    {"RSA", PK_PKIX1_RSA_OID, GNUTLS_PK_RSA},
+    {"DSA", PK_DSA_OID, GNUTLS_PK_DSA},
+    {"GOST R 34.10-2001", PK_GOST_R3410_2001_OID, 0},
+    {"GOST R 34.10-94", PK_GOST_R3410_94_OID, 0},
     {0, 0, 0}
 };
 
