@@ -23,7 +23,7 @@
  */
 
 int _gnutls_m_plaintext2compressed(gnutls_session_t session,
-				   gnutls_datum_t * compress,
+				   gnutls_datum_t * compressed,
 				   gnutls_datum_t plaintext);
 int _gnutls_m_compressed2plaintext(gnutls_session_t session,
 				   gnutls_datum_t * plain,
