@@ -36,7 +36,6 @@
 #include "gnutls_mpi.h"
 #include <gnutls_state.h>
 #include <gnutls_datum.h>
-#include <gnutls_alert.h>
 #include <gnutls_rsa_export.h>
 
 /* This file contains important thing for the TLS handshake procedure.
@@ -59,12 +58,12 @@ static int generate_normal_master(gnutls_session_t session,
 				  int keep_premaster)
 {
     int ret = 0;
-    opaque random[2 * TLS_RANDOM_SIZE + 1];
+    opaque rnd[2 * TLS_RANDOM_SIZE + 1];
     char buf[64];
 
-    memcpy(random, session->security_parameters.client_random,
+    memcpy(rnd, session->security_parameters.client_random,
 	   TLS_RANDOM_SIZE);
-    memcpy(&random[TLS_RANDOM_SIZE],
+    memcpy(&rnd[TLS_RANDOM_SIZE],
 	   session->security_parameters.server_random, TLS_RANDOM_SIZE);
 
     _gnutls_hard_log("INT: PREMASTER SECRET[%d]: %s\n", PREMASTER.size,
@@ -80,7 +79,7 @@ static int generate_normal_master(gnutls_session_t session,
     if (gnutls_protocol_get_version(session) == GNUTLS_SSL3) {
 	ret =
 	    _gnutls_ssl3_generate_random(PREMASTER.data, PREMASTER.size,
-					 random, 2 * TLS_RANDOM_SIZE,
+					 rnd, 2 * TLS_RANDOM_SIZE,
 					 TLS_MASTER_SIZE,
 					 session->security_parameters.
 					 master_secret);
@@ -89,7 +88,7 @@ static int generate_normal_master(gnutls_session_t session,
 	ret =
 	    _gnutls_PRF(PREMASTER.data, PREMASTER.size,
 			MASTER_SECRET, strlen(MASTER_SECRET),
-			random, 2 * TLS_RANDOM_SIZE, TLS_MASTER_SIZE,
+			rnd, 2 * TLS_RANDOM_SIZE, TLS_MASTER_SIZE,
 			session->security_parameters.master_secret);
     }
 
@@ -142,7 +141,7 @@ int _gnutls_send_server_kx_message(gnutls_session_t session, int again)
 
     ret =
 	_gnutls_send_handshake(session, data, data_size,
-			       GNUTLS_SERVER_KEY_EXCHANGE);
+			       GNUTLS_HANDSHAKE_SERVER_KEY_EXCHANGE);
     gnutls_free(data);
 
     if (ret < 0) {
@@ -184,7 +183,7 @@ int _gnutls_send_server_certificate_request(gnutls_session_t session,
     }
     ret =
 	_gnutls_send_handshake(session, data, data_size,
-			       GNUTLS_CERTIFICATE_REQUEST);
+			       GNUTLS_HANDSHAKE_CERTIFICATE_REQUEST);
     gnutls_free(data);
 
     if (ret < 0) {
@@ -222,7 +221,7 @@ int _gnutls_send_client_kx_message(gnutls_session_t session, int again)
     }
     ret =
 	_gnutls_send_handshake(session, data, data_size,
-			       GNUTLS_CLIENT_KEY_EXCHANGE);
+			       GNUTLS_HANDSHAKE_CLIENT_KEY_EXCHANGE);
     gnutls_free(data);
 
     if (ret < 0) {
@@ -278,7 +277,7 @@ int _gnutls_send_client_certificate_verify(gnutls_session_t session,
     }
     ret =
 	_gnutls_send_handshake(session, data,
-			       data_size, GNUTLS_CERTIFICATE_VERIFY);
+			       data_size, GNUTLS_HANDSHAKE_CERTIFICATE_VERIFY);
     gnutls_free(data);
 
     return ret;
@@ -304,7 +303,7 @@ int _gnutls_recv_server_kx_message(gnutls_session_t session)
 	ret =
 	    _gnutls_recv_handshake(session, &data,
 				   &datasize,
-				   GNUTLS_SERVER_KEY_EXCHANGE,
+				   GNUTLS_HANDSHAKE_SERVER_KEY_EXCHANGE,
 				   MANDATORY_PACKET);
 	if (ret < 0) {
 	    gnutls_assert();
@@ -337,7 +336,7 @@ int _gnutls_recv_server_certificate_request(gnutls_session_t session)
 	ret =
 	    _gnutls_recv_handshake(session, &data,
 				   &datasize,
-				   GNUTLS_CERTIFICATE_REQUEST,
+				   GNUTLS_HANDSHAKE_CERTIFICATE_REQUEST,
 				   OPTIONAL_PACKET);
 	if (ret < 0)
 	    return ret;
@@ -370,7 +369,7 @@ int _gnutls_recv_client_kx_message(gnutls_session_t session)
 	ret =
 	    _gnutls_recv_handshake(session, &data,
 				   &datasize,
-				   GNUTLS_CLIENT_KEY_EXCHANGE,
+				   GNUTLS_HANDSHAKE_CLIENT_KEY_EXCHANGE,
 				   MANDATORY_PACKET);
 	if (ret < 0)
 	    return ret;
@@ -437,7 +436,7 @@ int _gnutls_send_client_certificate(gnutls_session_t session, int again)
 				 */
 	ret =
 	    _gnutls_send_handshake(session, data, data_size,
-				   GNUTLS_CERTIFICATE_PKT);
+				   GNUTLS_HANDSHAKE_CERTIFICATE_PKT);
 	gnutls_free(data);
     }
 
@@ -478,7 +477,7 @@ int _gnutls_send_server_certificate(gnutls_session_t session, int again)
     }
     ret =
 	_gnutls_send_handshake(session, data, data_size,
-			       GNUTLS_CERTIFICATE_PKT);
+			       GNUTLS_HANDSHAKE_CERTIFICATE_PKT);
     gnutls_free(data);
 
     if (ret < 0) {
@@ -514,7 +513,7 @@ int _gnutls_recv_client_certificate(gnutls_session_t session)
 	ret =
 	    _gnutls_recv_handshake(session, &data,
 				   &datasize,
-				   GNUTLS_CERTIFICATE_PKT, optional);
+				   GNUTLS_HANDSHAKE_CERTIFICATE_PKT, optional);
 	if (ret < 0) {
 	    if (optional == OPTIONAL_PACKET &&
 		ret == GNUTLS_E_WARNING_ALERT_RECEIVED &&
@@ -581,7 +580,7 @@ int _gnutls_recv_server_certificate(gnutls_session_t session)
 	ret =
 	    _gnutls_recv_handshake(session, &data,
 				   &datasize,
-				   GNUTLS_CERTIFICATE_PKT,
+				   GNUTLS_HANDSHAKE_CERTIFICATE_PKT,
 				   MANDATORY_PACKET);
 	if (ret < 0) {
 	    gnutls_assert();
@@ -624,7 +623,7 @@ int _gnutls_recv_client_certificate_verify_message(gnutls_session_t
 	ret =
 	    _gnutls_recv_handshake(session, &data,
 				   &datasize,
-				   GNUTLS_CERTIFICATE_VERIFY,
+				   GNUTLS_HANDSHAKE_CERTIFICATE_VERIFY,
 				   OPTIONAL_PACKET);
 	if (ret < 0)
 	    return ret;
