@@ -178,6 +178,8 @@ uint _gnutls_session_size(gnutls_session_t session)
     return pack_size;
 }
 
+/* Load session data from a buffer.
+ */
 int _gnutls_session_unpack(gnutls_session_t session,
 			   const gnutls_datum_t * packed_session)
 {
@@ -255,7 +257,6 @@ int _gnutls_session_unpack(gnutls_session_t session,
 	    /* Delete the DH parameters. (this might need to be moved to a function)
 	     */
 	    info = session->key->auth_info;
-	    _gnutls_free_dh_info( &info->dh);
 	    memset(&info->dh, 0, sizeof(dh_info_st));
 	}
 	break;
@@ -389,7 +390,8 @@ static int _gnutls_pack_certificate_auth_info_size(cert_auth_info_t info)
     return pack_size + PACK_HEADER_SIZE + sizeof(uint32);
 }
 
-
+/* Load session data.
+ */
 int _gnutls_unpack_certificate_auth_info(cert_auth_info_t info,
 					 const gnutls_datum_t *
 					 packed_session)
@@ -404,8 +406,6 @@ int _gnutls_unpack_certificate_auth_info(cert_auth_info_t info,
 
     /* Delete the dh_info_st and rsa_info_st fields.
      */
-    _gnutls_free_dh_info( &info->dh);
-    _gnutls_free_rsa_info( &info->rsa_export);
     memset(&info->dh, 0, sizeof(dh_info_st));
     memset(&info->rsa_export, 0, sizeof(rsa_info_st));
 
