@@ -124,7 +124,7 @@ int _gnutls_session_cert_type_supported(gnutls_session_t session,
 {
     uint i;
     uint cert_found = 0;
-    const gnutls_certificate_credentials_t cred;
+    gnutls_certificate_credentials_t cred;
 
     if (session->security_parameters.entity == GNUTLS_SERVER) {
 	cred =
@@ -488,8 +488,9 @@ int _gnutls_dh_set_secret_bits(gnutls_session_t session, uint bits)
 /* This function will set in the auth info structure the
  * RSA exponent and the modulus.
  */
-int _gnutls_rsa_export_set_pubkey(gnutls_session_t session, mpi_t exp,
-				  mpi_t mod)
+int _gnutls_rsa_export_set_pubkey(gnutls_session_t session,
+				  mpi_t exponent,
+				  mpi_t modulus)
 {
     cert_auth_info_t info;
     int ret;
@@ -498,13 +499,13 @@ int _gnutls_rsa_export_set_pubkey(gnutls_session_t session, mpi_t exp,
     if (info == NULL)
 	return GNUTLS_E_INTERNAL_ERROR;
 
-    ret = _gnutls_mpi_dprint_lz(&info->rsa_export.modulus, mod);
+    ret = _gnutls_mpi_dprint_lz(&info->rsa_export.modulus, modulus);
     if (ret < 0) {
 	gnutls_assert();
 	return ret;
     }
 
-    ret = _gnutls_mpi_dprint_lz(&info->rsa_export.exponent, exp);
+    ret = _gnutls_mpi_dprint_lz(&info->rsa_export.exponent, exponent);
     if (ret < 0) {
 	gnutls_assert();
 	_gnutls_free_datum(&info->rsa_export.modulus);
