@@ -62,11 +62,12 @@ time_t _gnutls_x509_utcTime2gtime(const char *ttime);
 time_t _gnutls_x509_generalTime2gtime(const char *ttime);
 int _gnutls_x509_set_time(ASN1_TYPE c2, const char *where, time_t tim);
 
+int _gnutls_x509_decode_octet_string( const char* string_type,
+    const opaque* der, size_t der_size, opaque* output, size_t* output_size);
 int _gnutls_x509_oid_data2string(const char *OID, void *value,
-				 int value_size, char *res,
-				 size_t * res_size);
+    int value_size, char *res, size_t * res_size);
 int _gnutls_x509_data2hex(const opaque * data, size_t data_size,
-			  opaque * out, size_t * sizeof_out);
+    opaque * out, size_t * sizeof_out);
 
 const char *_gnutls_x509_oid2ldap_string(const char *OID);
 
@@ -97,7 +98,7 @@ int _gnutls_x509_encode_and_write_attribute(const char *given_oid,
     ASN1_TYPE asn1_struct, const char *where, const void *data,
     int sizeof_data, int multi);
 int _gnutls_x509_decode_and_read_attribute(ASN1_TYPE asn1_struct,
-    const char *where, char *oid, int oid_size, gnutls_datum_t * value, int multi);
+    const char *where, char *oid, int oid_size, gnutls_datum_t * value, int multi, int octet);
 
 int _gnutls_x509_get_pk_algorithm(ASN1_TYPE src, const char *src_name,
     unsigned int *bits);
