@@ -1,22 +1,24 @@
 /*
- *  Copyright (C) 2003 Nikos Mavroyanopoulos
- *  Copyright (C) 2004 Free Software Foundation
+ * Copyright (C) 2003, 2004, 2005 Free Software Foundation
  *
- *  This file is part of GNUTLS.
+ * Author: Nikos Mavroyanopoulos
  *
- *  The GNUTLS library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public   
- *  License as published by the Free Software Foundation; either 
- *  version 2.1 of the License, or (at your option) any later version.
+ * This file is part of GNUTLS.
  *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of 
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
+ * The GNUTLS library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public License
+ * as published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * USA
  *
  */
 
@@ -333,8 +335,8 @@ int _gnutls_x509_write_rsa_params(mpi_t * params, int params_size,
  * This is the "signatureAlgorithm" fields.
  */
 int _gnutls_x509_write_sig_params(ASN1_TYPE dst, const char *dst_name,
-				  gnutls_pk_algorithm_t pk_algorithm,
-				  mpi_t * params, int params_size)
+    gnutls_pk_algorithm_t pk_algorithm, gnutls_digest_algorithm_t dig,
+    mpi_t * params, int params_size)
 {
     gnutls_datum_t der;
     int result;
@@ -344,7 +346,7 @@ int _gnutls_x509_write_sig_params(ASN1_TYPE dst, const char *dst_name,
     _gnutls_str_cpy(name, sizeof(name), dst_name);
     _gnutls_str_cat(name, sizeof(name), ".algorithm");
 
-    pk = _gnutls_x509_sign_to_oid(pk_algorithm, GNUTLS_MAC_SHA);
+    pk = _gnutls_x509_sign_to_oid(pk_algorithm, dig);
     if (pk == NULL) {
 	gnutls_assert();
 	return GNUTLS_E_INVALID_REQUEST;
