@@ -134,7 +134,7 @@ static int encode_to_private_key_info(gnutls_x509_privkey_t pkey,
 				      gnutls_datum_t * der,
 				      ASN1_TYPE * pkey_info)
 {
-    int result;
+    int result, len;
     size_t size;
     opaque *data = NULL;
     opaque null = 0;
@@ -167,7 +167,7 @@ static int encode_to_private_key_info(gnutls_x509_privkey_t pkey,
      */
     result =
 	asn1_write_value(*pkey_info, "privateKeyAlgorithm.algorithm",
-			 PKIX1_RSA_OID, 1);
+			 PK_PKIX1_RSA_OID, 1);
     if (result != ASN1_SUCCESS) {
 	gnutls_assert();
 	result = _gnutls_asn2err(result);
@@ -230,8 +230,8 @@ static int encode_to_private_key_info(gnutls_x509_privkey_t pkey,
 
     /* DER Encode the generated private key info.
      */
-    size = 0;
-    result = asn1_der_coding(*pkey_info, "", NULL, &size, NULL);
+    len = 0;
+    result = asn1_der_coding(*pkey_info, "", NULL, &len, NULL);
     if (result != ASN1_MEM_ERROR) {
 	gnutls_assert();
 	result = _gnutls_asn2err(result);
@@ -240,14 +240,14 @@ static int encode_to_private_key_info(gnutls_x509_privkey_t pkey,
 
     /* allocate data for the der
      */
-    der->size = size;
-    der->data = gnutls_malloc(size);
+    der->size = len;
+    der->data = gnutls_malloc(len);
     if (der->data == NULL) {
 	gnutls_assert();
 	return GNUTLS_E_MEMORY_ERROR;
     }
 
-    result = asn1_der_coding(*pkey_info, "", der->data, &size, NULL);
+    result = asn1_der_coding(*pkey_info, "", der->data, &len, NULL);
     if (result != ASN1_SUCCESS) {
 	gnutls_assert();
 	result = _gnutls_asn2err(result);
@@ -381,7 +381,8 @@ int encode_to_pkcs8_key(schema_id schema, const gnutls_datum_t * der_key,
   * @password: the password that will be used to encrypt the key. 
   * @flags: an ORed sequence of gnutls_pkcs_encrypt_flags_t
   * @output_data: will contain a private key PEM or DER encoded
-  * @output_data_size: holds the size of output_data (and will be replaced by the actual size of parameters)
+  * @output_data_size: holds the size of output_data (and will be
+  *   replaced by the actual size of parameters)
   *
   * This function will export the private key to a PKCS8 structure.
   * Currently only RSA keys can be exported since there is no documented
@@ -393,14 +394,15 @@ int encode_to_pkcs8_key(schema_id schema, const gnutls_datum_t * der_key,
   * encryption schemas, or ASCII for the PKCS12 schemas.
   *
   * If the buffer provided is not long enough to hold the output, then
-  * &output_data_size is updated and GNUTLS_E_SHORT_MEMORY_BUFFER will be returned.
+  * *output_data_size is updated and GNUTLS_E_SHORT_MEMORY_BUFFER will
+  * be returned.
   *
   * If the structure is PEM encoded, it will have a header
   * of "BEGIN ENCRYPTED PRIVATE KEY" or "BEGIN PRIVATE KEY" if
   * encryption is not used.
   *
-  * In case of failure a negative value will be returned, and
-  * 0 on success.
+  * Return value: In case of failure a negative value will be
+  *   returned, and 0 on success.
   *
   **/
 int gnutls_x509_privkey_export_pkcs8(gnutls_x509_privkey_t key,
@@ -744,7 +746,7 @@ int decode_private_key_info(const gnutls_datum_t * der,
 
     /* we only support RSA private keys.
      */
-    if (strcmp(oid, PKIX1_RSA_OID) != 0) {
+    if (strcmp(oid, PK_PKIX1_RSA_OID) != 0) {
 	gnutls_assert();
 	_gnutls_x509_log
 	    ("PKCS #8 private key OID '%s' is unsupported.\n", oid);
@@ -1196,7 +1198,7 @@ static int decrypt_data(schema_id schema, ASN1_TYPE pkcs8_asn,
     int result;
     int data_size;
     opaque *data = NULL, *key = NULL;
-    gnutls_datum_t dkey, div;
+    gnutls_datum_t dkey, d_iv;
     cipher_hd_t ch = NULL;
     int key_size;
 
@@ -1263,9 +1265,9 @@ static int decrypt_data(schema_id schema, ASN1_TYPE pkcs8_asn,
     dkey.data = key;
     dkey.size = key_size;
 
-    div.data = (opaque *) enc_params->iv;
-    div.size = enc_params->iv_size;
-    ch = _gnutls_cipher_init(enc_params->cipher, &dkey, &div);
+    d_iv.data = (opaque *) enc_params->iv;
+    d_iv.size = enc_params->iv_size;
+    ch = _gnutls_cipher_init(enc_params->cipher, &dkey, &d_iv);
 
     gnutls_afree(key);
     key = NULL;
@@ -1636,7 +1638,7 @@ static int encrypt_data(const gnutls_datum_t * plain,
     int result;
     int data_size;
     opaque *data = NULL;
-    gnutls_datum_t div;
+    gnutls_datum_t d_iv;
     cipher_hd_t ch = NULL;
     opaque pad, pad_size;
 
@@ -1663,9 +1665,9 @@ static int encrypt_data(const gnutls_datum_t * plain,
 
     data_size = plain->size + pad;
 
-    div.data = (opaque *) enc_params->iv;
-    div.size = enc_params->iv_size;
-    ch = _gnutls_cipher_init(enc_params->cipher, key, &div);
+    d_iv.data = (opaque *) enc_params->iv;
+    d_iv.size = enc_params->iv_size;
+    ch = _gnutls_cipher_init(enc_params->cipher, key, &d_iv);
 
     if (ch == GNUTLS_CIPHER_FAILED) {
 	gnutls_assert();
