@@ -197,6 +197,9 @@ static inline
 
 
 /* 
+ * Verifies the given certificate again a certificate list of
+ * trusted CAs.
+ *
  * Returns only 0 or 1. If 1 it means that the certificate 
  * was successfuly verified.
  *
@@ -318,7 +321,7 @@ unsigned int _gnutls_x509_verify_certificate(
     /* Verify the last certificate in the certificate path
      * against the trusted CA certificate list.
      *
-     * If no CAs are present returns NOT_TRUSTED. Thus works
+     * If no CAs are present returns CERT_INVALID. Thus works
      * in self signed etc certificates.
      */
     ret =
@@ -356,6 +359,10 @@ unsigned int _gnutls_x509_verify_certificate(
 	if (i - 1 < 0)
 	    break;
 
+        /* note that here we disable this V1 CA flag. So that no version 1
+         * certificates can exist in a supplied chain.
+         */
+        flags ^= GNUTLS_VERIFY_ALLOW_X509_V1_CA_CRT;
 	if ((ret =
 	     _gnutls_verify_certificate2(certificate_list[i-1],
                   &certificate_list[i], 1, flags, NULL)) == 0) {
@@ -500,7 +507,7 @@ dsa_verify_sig(const gnutls_datum_t * text,
     gnutls_datum_t digest;
     GNUTLS_HASH_HANDLE hd;
 
-    hd = _gnutls_hash_init(GNUTLS_MAC_SHA);
+    hd = _gnutls_hash_init(GNUTLS_MAC_SHA1);
     if (hd == NULL) {
 	gnutls_assert();
 	return GNUTLS_E_HASH_FAILED;
@@ -643,9 +650,9 @@ int _gnutls_x509_privkey_verify_signature(const gnutls_datum_t * tbs,
   * For a more detailed verification status use gnutls_x509_crt_verify() per list
   * element.
   *
-  * GNUTLS_CERT_INVALID\: the certificate chain is not valid.
+  * GNUTLS_CERT_INVALID: the certificate chain is not valid.
   *
-  * GNUTLS_CERT_REVOKED\: a certificate in the chain has been revoked.
+  * GNUTLS_CERT_REVOKED: a certificate in the chain has been revoked.
   *
   * Returns 0 on success and a negative value in case of an error.
   *
