@@ -36,7 +36,6 @@
 #include <dn.h>
 #include <extensions.h>
 #include <libtasn1.h>
-#include <gnutls_ui.h>
 #include <mpi.h>
 #include <privkey.h>
 #include <verify.h>
@@ -263,9 +262,9 @@ int gnutls_x509_crt_get_issuer_dn(gnutls_x509_crt_t cert, char *buf,
   * @sizeof_buf: initially holds the size of @buf
   *
   * This function will extract the part of the name of the Certificate
-  * issuer specified by the given OID. The output will be encoded as
-  * described in RFC2253. The output string will be ASCII or UTF-8
-  * encoded, depending on the certificate data.
+  * issuer specified by the given OID. The output, if the raw flag is not
+  * used, will be encoded as described in RFC2253. Thus a string that is
+  * ASCII or UTF-8 encoded, depending on the certificate data.
   *
   * Some helper macros with popular OIDs can be found in gnutls/x509.h
   * If raw flag is zero, this function will only return known OIDs as
@@ -363,11 +362,12 @@ int gnutls_x509_crt_get_dn(gnutls_x509_crt_t cert, char *buf,
   * @oid: holds an Object Identified in null terminated string
   * @indx: In case multiple same OIDs exist in the RDN, this specifies which to send. Use zero to get the first one.
   * @raw_flag: If non zero returns the raw DER data of the DN part.
-  * @buf: a pointer to a structure to hold the name (may be null)
+  * @buf: a pointer where the DN part will be copied (may be null).
   * @sizeof_buf: initially holds the size of @buf
   *
   * This function will extract the part of the name of the Certificate
-  * subject, specified by the given OID. The output string will be
+  * subject specified by the given OID. The output, if the raw flag is not
+  * used, will be encoded as described in RFC2253. Thus a string that is
   * ASCII or UTF-8 encoded, depending on the certificate data.
   *
   * Some helper macros with popular OIDs can be found in gnutls/x509.h
