@@ -41,7 +41,6 @@
 #include <sign.h>
 #include <extensions.h>
 #include <libtasn1.h>
-#include <gnutls_ui.h>
 
 static void disable_optional_stuff(gnutls_x509_crt_t cert);
 
@@ -248,7 +247,7 @@ int gnutls_x509_crt_set_extension_by_oid(gnutls_x509_crt_t crt,
     unsigned int critical)
 {
     int result;
-    gnutls_datum_t der_data = {buf, sizeof_buf};
+    gnutls_datum_t der_data = {(void*)buf, sizeof_buf};
 
     if (crt == NULL) {
 	gnutls_assert();
