@@ -22,6 +22,8 @@
 
 #include <config.h>
 
+
+
 #ifndef ENABLE_SRP
 
 #include <stdio.h>
@@ -32,6 +34,11 @@ int main(int argc, char **argv)
     return 1;
 };
 
+void srptool_version(void)
+{
+    fprintf(stderr, "GNU TLS dummy srptool.\n");
+}
+
 #else
 
 #include <stdio.h>
@@ -62,12 +69,18 @@ int main(int argc, char **argv)
  */
 
 int crypt_int(const char *username, const char *passwd, int salt,
-	      char *tpasswd_conf, char *tpasswd, int uindex);
+    char *tpasswd_conf, char *tpasswd, int uindex);
 static int read_conf_values(gnutls_datum * g, gnutls_datum * n, char *str);
 static int _verify_passwd_int(const char *username, const char *passwd,
-			      char *verifier, char *salt,
-			      const gnutls_datum * g,
-			      const gnutls_datum * n);
+    char *verifier, char *salt,
+    const gnutls_datum * g, const gnutls_datum * n);
+
+void srptool_version(void)
+{
+    fprintf(stderr, "GNU TLS srptool, ");
+    fprintf(stderr, "version %s. Libgnutls %s.\n", LIBGNUTLS_VERSION,
+	    gnutls_check_version(NULL));
+}
 
 
 static void print_num(const char *msg, const gnutls_datum * num)
@@ -413,6 +426,10 @@ int main(int argc, char **argv)
     salt = 16;
 
     passwd = getpass("Enter password: ");
+    if (passwd==NULL) {
+       fprintf(stderr, "Please specify a password\n");
+       return -1;
+    }
 
 /* not ready yet */
     if (info.verify != 0) {
